@@ -21,7 +21,7 @@ from PySide2.QtCore import *
 from PySide2.QtGui import *
 
 # Custom imports
-from cutevariant.core.querybuilder import build_full_sql_query, fields_to_vql
+from cutevariant.core.querybuilder import build_sql_query
 from cutevariant.core import sql
 
 from cutevariant.core import command as cmd
@@ -50,8 +50,8 @@ class VariantModel(QAbstractTableModel):
     fields.
 
     Signals:
-        variant_loaded(bool): Emit when variant are loaded 
-        count_loaded(bool): Emit when total count are loaded 
+        variant_loaded(bool): Emit when variant are loaded
+        count_loaded(bool): Emit when total count are loaded
         error_raised(str): Emit message when threads or something else encounter errors
     """
 
@@ -86,7 +86,8 @@ class VariantModel(QAbstractTableModel):
         # Field names as keys, descriptions as values
         self.fields_descriptions = None
 
-        self.fields = ["chr", "pos", "ref", "alt"]
+        self.fields = ["chr", "pos", "ref", "alt", "ann.gene"]
+
         self.filters = dict()
         self.source = "variants"
         self.group_by = []
@@ -166,7 +167,7 @@ class VariantModel(QAbstractTableModel):
     def columnCount(self, parent=QModelIndex()):
         """Overrided: Return column count of parent .
 
-        Parent is not used here 
+        Parent is not used here
         """
 
         #  Check integrity for unit test
@@ -192,18 +193,12 @@ class VariantModel(QAbstractTableModel):
     def max_cache_size(self):
         return self._load_variant_cache.maxsize
 
-    def is_variant_loading(self):
-        return self._load_variant_cache.isRunning()
-
-    def is_count_loading(self):
-        return self._load_count_thread.isRunning()
-
     def clear(self):
         """Reset the current model
 
-            - clear variants list
-            - total of variants is set to 0
-            - emit variant_loaded signal
+        - clear variants list
+        - total of variants is set to 0
+        - emit variant_loaded signal
         """
         self.beginResetModel()
         self.variants.clear()
@@ -240,6 +235,12 @@ class VariantModel(QAbstractTableModel):
                 else:
                     return str(self.variant(index.row())[column_name])
 
+            if role == Qt.ToolTipRole:
+                value = str(self.variant(index.row())[column_name])
+                return value
+
+        return None
+
     def headerData(self, section, orientation=Qt.Horizontal, role=Qt.DisplayRole):
         """Overrided: Return column name and display tooltips on headers
 
@@ -315,7 +316,7 @@ class VariantModel(QAbstractTableModel):
     def interrupt(self):
         """Interrupt current query if active
 
-        This is a blocking function... 
+        This is a blocking function...
 
         call interrupt and wait for the error_raised signals ...
         If nothing happen after 1000 ms, by pass and continue
@@ -385,10 +386,8 @@ class VariantModel(QAbstractTableModel):
         self._finished_thread_count = 0
         # LOGGER.debug("Page queried: %s", self.page)
 
-        print("ORDER", self.order_by, self.order_desc)
-
         # Store SQL query for debugging purpose
-        self.debug_sql = build_full_sql_query(
+        self.debug_sql = build_sql_query(
             self.conn,
             fields=self.fields,
             source=self.source,
@@ -401,6 +400,7 @@ class VariantModel(QAbstractTableModel):
             having=self.having,
         )
 
+        print(self.debug_sql)
         # Create load_func to run asynchronously: load variants
         load_func = functools.partial(
             cmd.select_cmd,
@@ -454,11 +454,12 @@ class VariantModel(QAbstractTableModel):
 
     def _on_variant_loaded(self):
         """
-        Triggered when variant_thread is finished 
+        Triggered when variant_thread is finished
 
         """
 
         #  Compute time elapsed since loading
+
         self._end_timer = time.perf_counter()
         self.elapsed_time = self._end_timer - self._start_timer
 
@@ -493,7 +494,7 @@ class VariantModel(QAbstractTableModel):
 
     def _on_count_loaded(self):
         """
-        Triggered when count_threaed is finished 
+        Triggered when count_threaed is finished
         """
 
         # Save cache
@@ -550,7 +551,8 @@ class VariantModel(QAbstractTableModel):
         """
         if column < self.columnCount():
             field = self.fields[column - 1]
-            self.order_by = field
+
+            self.order_by = [field]
             self.order_desc = order == Qt.DescendingOrder
             self.load()
 
@@ -705,6 +707,7 @@ class VariantView(QWidget):
         self.page_box.setValidator(QIntValidator())
         self.page_box.setFixedWidth(50)
         self.page_box.setValidator(QIntValidator())
+        self.page_box.setFocusPolicy(Qt.NoFocus)
 
         # Display nb of variants/groups and pages
         self.info_label = QLabel()
@@ -723,8 +726,8 @@ class VariantView(QWidget):
         self.bottom_bar.addWidget(self.info_label)
         self.loading_action = self.bottom_bar.addWidget(self.loading_label)
 
-        self.bottom_bar.setIconSize(QSize(16, 16))
-        self.bottom_bar.setMaximumHeight(30)
+        # self.bottom_bar.setIconSize(QSize(16, 16))
+        # self.bottom_bar.setMaximumHeight(30)
         self.bottom_bar.setContentsMargins(0, 0, 0, 0)
 
         self.pagging_actions = []
@@ -871,9 +874,11 @@ class VariantView(QWidget):
         else:
             text = self.tr("{} line(s) {} page(s)")
 
-        print("loaded")
         self.info_label.setText(text.format(self.model.total, self.model.pageCount()))
 
+        #  Set focus to view ! Otherwise it stay on page_box
+        self.view.setFocus(Qt.ActiveWindowFocusReason)
+
     def set_formatter(self, formatter):
         self.delegate.formatter = formatter
         self.view.reset()
@@ -1000,14 +1005,14 @@ class VariantView(QWidget):
     def _get_links(self) -> list:
         """Get links from settings
 
-        Return list of links from QSettings 
+        Return list of links from QSettings
 
         Exemples:
             {
             "name":"google",
             "url": "http://www.google.fr/q={}",
-            "is_browser": True   # Open with browser  
-            "is_default": True   # is a default action 
+            "is_browser": True   # Open with browser
+            "is_default": True   # is a default action
             }
 
         """
@@ -1116,15 +1121,15 @@ class VariantView(QWidget):
             urllib.request.urlopen(url.toString(), timeout=10)
 
     def _create_url(self, format_string: str, variant: dict) -> QUrl:
-        """Create a link from a format string and a variant data 
-        
+        """Create a link from a format string and a variant data
+
         Args:
             format_string (str): a string with format group like : http://www.google.fr?q={chr}
             variant (dict): a variant dict returned by sql.get_one_variant.
-        
+
         Returns:
             QUrl: return url or return None
-        
+
         """
         field_names = {
             name
@@ -1210,6 +1215,17 @@ class VariantView(QWidget):
             index, QItemSelectionModel.SelectCurrent | QItemSelectionModel.Rows
         )
 
+    def keyPressEvent(self, event: QKeyEvent):
+        """
+        Handles key press events on the VariantView
+        Can be used to filter out unexpected behavior with KeySequence conflicts
+        """
+        if event.matches(
+            QKeySequence.Copy
+        ):  # Default behavior from QTableView only copies the index that the mouse hovers
+            self.copy_to_clipboard()  # So copy to clipboard to get the expected behavior in contextMenuEvent
+            event.accept()  # Accept the event before the QTableView handles it in a terrible way
+
     def copy_to_clipboard(self):
         """Copy the selected variant(s) into the clipboard
 
@@ -1248,9 +1264,9 @@ class VariantView(QWidget):
             self._open_url(url, link["is_browser"])
 
     def on_double_clicked(self, index: QModelIndex):
-        """ 
+        """
         React on double clicked
-        TODO : duplicate code with ContextMenu Event ! Need to refactor a bit 
+        TODO : duplicate code with ContextMenu Event ! Need to refactor a bit
         """
 
         self._open_default_link(index)
@@ -1262,6 +1278,9 @@ class VariantViewWidget(plugin.PluginWidget):
     variant_clicked = Signal(dict)
     LOCATION = plugin.CENTRAL_LOCATION
 
+    # Emitted when the variants are both counted and loaded in the view. Provides the variants count and the elapsed time (in seconds) to execute the query
+    variants_load_finished = Signal(int, float)
+
     ENABLE = True
 
     def __init__(self, parent=None):
@@ -1271,13 +1290,6 @@ class VariantViewWidget(plugin.PluginWidget):
         self.splitter = QSplitter(Qt.Horizontal)
         self.main_right_pane = VariantView(parent=self)
 
-        # No popup menu on this one
-        self.groupby_left_pane = VariantView(parent=self, show_popup_menu=False)
-        self.groupby_left_pane.hide()
-        # Force selection of first item after refresh
-        self.groupby_left_pane.row_to_be_selected = 0
-
-        self.splitter.addWidget(self.groupby_left_pane)
         self.splitter.addWidget(self.main_right_pane)
 
         # Make resizable TODO : ugly ... Make it nicer
@@ -1299,22 +1311,6 @@ class VariantViewWidget(plugin.PluginWidget):
         # PS: Actions with QAction::LowPriority will not show the text labels
         self.top_bar.setToolButtonStyle(Qt.ToolButtonTextBesideIcon)
 
-        # checkable group action
-        self.groupby_action = self.top_bar.addAction(
-            FIcon(0xF14E0), self.tr("Group by"), self.on_group_changed
-        )
-        self.groupby_action.setToolTip(
-            self.tr("Group variants according to choosen columns")
-        )
-        self.groupby_action.setCheckable(True)
-        self.groupby_action.setChecked(False)
-
-        # groupbylist
-        self.groupbylist_action = self.top_bar.addAction("chr,pos,ref")
-        self.groupbylist_action.setVisible(False)
-        self.groupbylist_action.triggered.connect(self._show_group_dialog)
-
-        self.top_bar.addSeparator()
         # Save selection
         self.save_action = self.top_bar.addAction(
             FIcon(0xF0F87), self.tr("Save selection"), self.on_save_selection
@@ -1374,21 +1370,19 @@ class VariantViewWidget(plugin.PluginWidget):
             lambda x, _: self.on_variant_clicked(x)
         )
 
-        self.groupby_left_pane.view.selectionModel().currentRowChanged.connect(
-            lambda x, _: self.on_variant_clicked(x)
-        )
-        self.groupby_left_pane.no_variant.connect(self.on_no_variant)
-        # Connect errors from async runnables
         self.main_right_pane.error_raised.connect(self.set_message)
-        self.groupby_left_pane.error_raised.connect(self.set_message)
+
+        # Connect model's signal load_finished to this signal's load_finished
+        self.main_right_pane.model.load_finished.connect(
+            lambda: self.variants_load_finished.emit(
+                self.main_right_pane.model.total,
+                self.main_right_pane.model.elapsed_time,
+            )
+        )
 
         # Default group
         self.last_group = ["chr"]
 
-        # Save fields between group/ungroup
-        self.save_fields = list()
-        self.save_filters = list()
-
     def add_available_formatters(self):
         """Populate the formatters
 
@@ -1426,7 +1420,6 @@ class VariantViewWidget(plugin.PluginWidget):
 
         formatter_class = self.formatter_combo.currentData()
         self.main_right_pane.set_formatter(formatter_class())
-        self.groupby_left_pane.set_formatter(formatter_class())
         # Save formatter setting
         settings.setValue("formatter", formatter_class.__name__)
 
@@ -1435,7 +1428,6 @@ class VariantViewWidget(plugin.PluginWidget):
         self.conn = conn
         # Set connections of models
         self.main_right_pane.conn = self.conn
-        self.groupby_left_pane.conn = self.conn
 
         self.on_refresh()
 
@@ -1443,32 +1435,29 @@ class VariantViewWidget(plugin.PluginWidget):
         """Overrided from PluginWidget"""
         # Save default data with current query attributes
         # See load(), we use this attr to restore fields after grouping
-        self.save_fields = self.mainwindow.state.fields
-        self.save_filters = self.mainwindow.state.filters
 
-        self.main_right_pane.fields = self.mainwindow.state.fields
-        self.main_right_pane.source = self.mainwindow.state.source
-        self.main_right_pane.filters = self.mainwindow.state.filters
-        # Set current group_by to left pane
-        self._set_groups(self.mainwindow.state.group_by)
+        if self.mainwindow:
+            self.save_fields = self.mainwindow.state.fields
+            self.save_filters = self.mainwindow.state.filters
+
+            self.main_right_pane.fields = self.mainwindow.state.fields
+            self.main_right_pane.source = self.mainwindow.state.source
+            self.main_right_pane.filters = self.mainwindow.state.filters
 
         # Set formatter
         formatter_class = self.formatter_combo.currentData()
 
         #        formatter_class = next(formatter.find_formatters())
         self.main_right_pane.set_formatter(formatter_class())
-        self.groupby_left_pane.set_formatter(formatter_class())
 
         # Clear only the variant cache ! Because user can edit data
         self.main_right_pane.model.clear_variant_cache()
-        self.groupby_left_pane.model.clear_variant_cache()
 
         # Load ui
         self.load(reset_page=True)
 
     def on_interrupt(self):
         self.main_right_pane.model.interrupt()
-        self.groupby_left_pane.model.interrupt()
 
     def on_save_selection(self):
         """Triggered on 'save_selection' button
@@ -1516,84 +1505,24 @@ class VariantViewWidget(plugin.PluginWidget):
         """
         self.main_right_pane.model.clear()
 
-    def _is_grouped(self) -> bool:
-        """Return grouped mode status of the view"""
-        # print("is grouped ?")
-        # print("left", self.groupby_left_pane.model.group_by)
-        # print("right", self.main_right_pane.model.group_by)
-        return self.groupby_left_pane.group_by != []
-
     def load(self, reset_page=False):
         """Load all views
 
         Called by on_refresh, on_group_changed, and _show_group_dialog
         Display/hide groupby_left_pane on user demand.
         """
-        is_grouped = self._is_grouped()
-        # Left pane and groupbylist are visible in group mode
-        self.groupby_left_pane.setVisible(is_grouped)
-        self.groupbylist_action.setVisible(is_grouped)
-
-        self.groupby_action.blockSignals(True)
-        self.groupby_action.setChecked(is_grouped)
-        self.groupby_action.blockSignals(False)
 
         # Hide potential errors
         self.log_edit.hide()
 
-        if is_grouped:
-            # Ungrouped => grouped or already grouped
-            # Groupby fields become left pane fields
-            self.groupby_left_pane.fields = self.groupby_left_pane.group_by
-            # Prune right fields with left fields => avoid redundancy of information
-            self.main_right_pane.fields = [
-                field
-                for field in self.save_fields
-                if field not in self.groupby_left_pane.group_by
-            ]
-            self.groupby_left_pane.filters = self.save_filters
-            self.groupby_left_pane.source = self.main_right_pane.source
-
-            # Refresh models
-            # right pane: Useless, except if we modify fields like above
-            # But refreshing left pane triggers right pane refreshing
-            # So => do not do it here
-            # self.main_right_pane.load()
-            self.groupby_left_pane.load(reset_page)
-        else:
-            # Grouped => ungrouped
-            # Restore fields
-            self.main_right_pane.fields = self.save_fields
-            # Restore filters
-            self.main_right_pane.filters = self.save_filters
-            # Refresh model
-            self.main_right_pane.load(reset_page)
-            # print("saved right:", self.save_fields)
-
-    def on_group_changed(self):
-        """Set group by fields when group by button is clicked"""
-        is_checked = self.groupby_action.isChecked()
-        is_grouped = self._is_grouped()
-        if is_checked and not is_grouped:
-            # Group it
-            self.groupby_action.setIcon(FIcon(0xF14E1))
-            self.groupby_action.setToolTip(self.tr("Ungroup variants"))
-            # Recall previous/default group
-            self._set_groups(self.last_group)
-        else:
-            # Ungroup it
-            self.groupby_action.setIcon(FIcon(0xF14E0))
-            self.groupby_action.setToolTip(
-                self.tr("Group variants according to choosen columns")
-            )
-            # Save current group
-            self.last_group = self.groupby_left_pane.group_by
-        if not is_checked:
-            # Reset to default group (chr set in _show_group_dialog)
-            self._set_groups([])
-
-        self.load()
-        self._refresh_vql_editor()
+        # Grouped => ungrouped
+        # Restore fields
+        self.main_right_pane.fields = self.save_fields
+        # Restore filters
+        self.main_right_pane.filters = self.save_filters
+        # Refresh model
+        self.main_right_pane.load(reset_page)
+        # print("saved right:", self.save_fields)
 
     def on_variant_clicked(self, index: QModelIndex):
         """React on variant clicked
@@ -1604,113 +1533,18 @@ class VariantViewWidget(plugin.PluginWidget):
                 selection models to locate an item in the model.
         """
 
-        if index.model() == self.groupby_left_pane.view.model():
-            # Variant clicked on left pane => refresh the right pane
-            variant = self.groupby_left_pane.model.variant(index.row())
-
-            if self._is_grouped():
-                # Restore fields
-                self.groupby_left_pane.source = self.main_right_pane.source
-
-                # Forge a special filter to display the current variant
-                and_list = [
-                    {
-                        "field": field,
-                        "operator": "=",
-                        "value": variant[fields_to_vql(field)],
-                    }
-                    for field in self.groupby_left_pane.group_by
-                ]
-
-                if self.save_filters:
-                    # Build a new filter dict/tree based on the current one
-                    filters = copy.deepcopy(self.save_filters)
-
-                    if "AND" in self.save_filters:
-                        # {'AND': [...]}
-                        # => Just add our additional constraints joined by AND
-                        filters["AND"] += and_list
-                    elif "OR" in self.save_filters:
-                        # {'OR': [...]}
-                        # => Insert the previous filter as a child of a AND constraint
-                        # Ours are mandatory
-                        # {'AND': [{'OR': [...]}, ...]}
-                        and_list.append(filters)
-                        filters = {"AND": and_list}
-                else:
-                    # New filter => {'AND': [...]}
-                    filters = {"AND": and_list}
-
-                LOGGER.debug("Filters for right pane for grouped variants %s", filters)
-
-                self.main_right_pane.filters = filters
-
-                # Update right pane only
-                self.main_right_pane.load(reset_page=True)
-
         if index.model() == self.main_right_pane.view.model():
             # Variant clicked on right pane
             variant = self.main_right_pane.model.variant(index.row())
 
-        # Refresh the current variant of mainwindow and plugins
-        self.mainwindow.state.current_variant = variant
-        # Request a refresh of the variant_info plugin
-        self.mainwindow.refresh_plugin("variant_info")
-
-    def _show_group_dialog(self):
-        """Show a dialog window to select group fields"""
-        dialog = QDialog(self)
-
-        view = QListWidget()
-        box = QVBoxLayout()
-        buttons = QDialogButtonBox(QDialogButtonBox.Ok | QDialogButtonBox.Cancel)
-        box.addWidget(view)
-        box.addWidget(buttons)
-        buttons.accepted.connect(dialog.accept)
-        buttons.rejected.connect(dialog.reject)
-
-        # Populate the list of fields with their check status
-        for field in self.save_fields:
-            item = QListWidgetItem()
-            item.setText(fields_to_vql(field))
-            item.setData(Qt.UserRole, field)
-            if field in self.groupby_left_pane.group_by:
-                item.setCheckState(Qt.Checked)
-            else:
-                item.setCheckState(Qt.Unchecked)
-
-            view.addItem(item)
-        dialog.setLayout(box)
-
-        if dialog.exec_() == QDialog.Accepted:
-
-            selected_fields = []
-            for i in range(view.count()):
-                item = view.item(i)
-                if item.checkState() == Qt.Checked:
-                    selected_fields.append(item.data(Qt.UserRole))
-
-            # if no group force chr
-            if not selected_fields:
-                selected_fields = ["chr"]
-
-            # Set current group_by to left pane
-            self._set_groups(selected_fields)
-            # Reload ui
-            self.load()
-            self._refresh_vql_editor()
-
-    def _set_groups(self, grouped_fields):
-        """Set fields on groupby_left_pane and refresh text on groupby action"""
-        self.groupby_left_pane.group_by = grouped_fields
-        self.groupbylist_action.setText(
-            ",".join([fields_to_vql(field) for field in grouped_fields])
-        )
+        if self.mainwindow:
+            self.mainwindow.state.current_variant = variant
+            # Request a refresh of the variant_info plugin
+            self.mainwindow.refresh_plugin("variant_info")
 
     def _refresh_vql_editor(self):
         """Force refresh of vql_editor if loaded"""
         if "vql_editor" in self.mainwindow.plugins:
-            self.mainwindow.state.group_by = self.groupby_left_pane.group_by
             # Request a refresh of the vql_editor plugin
             self.mainwindow.refresh_plugin("vql_editor")
 
@@ -1759,25 +1593,15 @@ if __name__ == "__main__":
 
     app = QApplication(sys.argv)
 
-    m = QStringListModel()
-    m.setStringList(["salut", "sach"])
-    w = LoadingTableView()
-    w.setModel(m)
+    conn = sql.get_sql_connection("/home/sacha/Dev/cutevariant/corpos3.db")
+
+    w = VariantViewWidget()
+    w.conn = conn
+    w.main_right_pane.model.conn = conn
+    w.main_right_pane.load()
+    # w.main_view.model.group_by = ["chr","pos","ref","alt"]
+    # w.on_refresh()
+
     w.show()
 
-    # conn = sql.get_sql_connection(":memory:")
-    # reader = VcfReader(
-    #     open("/home/sacha/Dev/cutevariant/examples/test.snpeff.vcf"), "snpeff"
-    # )
-    # import_reader(conn, reader)
-
-    # w = VariantViewWidget()
-    # w.conn = conn
-    # w.main_right_pane.model.conn = conn
-    # w.main_right_pane.load()
-    # # w.main_view.model.group_by = ["chr","pos","ref","alt"]
-    # # w.on_refresh()
-
-    # w.show()
-
     app.exec_()
