@@ -1,7 +1,10 @@
 from PySide2.QtWidgets import QApplication
+
 __title__ = "VQL Editor"
 __description__ = "A VQL editor"
-__long_description__ = QApplication.instance().translate("vql_editor", """
+__long_description__ = QApplication.instance().translate(
+    "vql_editor",
+    """
 <p>This plugin allows you to manage most of the work that can be done in a 
 Cutevariant project by writing and executing VQL queries.</p>
 
@@ -16,6 +19,7 @@ as well as the keywords of the language, please see the project wiki page:</p>
 
 <a href="https://github.com/labsquare/cutevariant/wiki/VQL-language">
 https://github.com/labsquare/cutevariant/wiki/VQL-language</a>
-""")
+""",
+)
 __author__ = "Sacha schutz"
 __version__ = "1.0.0"
